Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(270)

Unified Diff: media/formats/webm/webm_video_client.h

Issue 1786733004: Revert of media config: expand is_encrypted to a struct. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/formats/webm/webm_tracks_parser.cc ('k') | media/formats/webm/webm_video_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/formats/webm/webm_video_client.h
diff --git a/media/formats/webm/webm_video_client.h b/media/formats/webm/webm_video_client.h
index d746df9166459d2ec70c0f4189ba55c408d6dcad..dfdc5f6f671f1d556f667f34f02d575e4d6f7d47 100644
--- a/media/formats/webm/webm_video_client.h
+++ b/media/formats/webm/webm_video_client.h
@@ -15,7 +15,6 @@
#include "media/formats/webm/webm_parser.h"
namespace media {
-class EncryptionScheme;
class VideoDecoderConfig;
// Helper class used to parse a Video element inside a TrackEntry element.
@@ -28,15 +27,15 @@
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
// |encryption_scheme| and the fields parsed from the last video track element
// this object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or
// video track element fields. The contents of |config| are undefined in this
// case and should not be relied upon.
bool InitializeConfig(const std::string& codec_id,
const std::vector<uint8_t>& codec_private,
- const EncryptionScheme& encryption_scheme,
+ bool is_encrypted,
VideoDecoderConfig* config);
private:
« no previous file with comments | « media/formats/webm/webm_tracks_parser.cc ('k') | media/formats/webm/webm_video_client.cc » ('j') | no next file with comments »
@@ -28,15 +27,15 @@
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
- // |encryption_scheme| and the fields parsed from the last video track element
- // this object was used to parse.
+ // |is_encrypted| and the fields parsed from the last video track element this
+ // object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or

Powered by Google App Engine
This is Rietveld 408576698